@@ -113,10 +113,6 @@ def setup(settings_path=None, **settings_patches):
                 # mod_uwsgi
                 local('apxs -i -c apache2/mod_uwsgi.c')
                 local('echo "LoadModule uwsgi_module modules/mod_uwsgi.so" > /etc/httpd/conf.d/uwsgi.conf')
-                # Beanstalk
-                local('echo "Include %s" > /etc/httpd/conf.d/beanstalk.conf' % apache_conf_path())
-                # Restart apache
-                local('/etc/init.d/httpd reload')
 
     # Do you have user "beanstalk"?
     with settings(hide('everything'), warn_only=True):
@@ -165,6 +161,7 @@ def setup(settings_path=None, **settings_patches):
     # Apache conf
     local('echo "# Beanstalk Apache conf" > %s' % apache_conf_path())
     local('chown beanstalk:beanstalk %s' % apache_conf_path())
+    local('echo "Include %s" > /etc/httpd/conf.d/beanstalk.conf' % apache_conf_path())
 
     local('chown -R beanstalk:beanstalk %s' % beanstalk_stack_base)
     local('/etc/init.d/sshd restart')
